'''
Python Expense Tracker 
This application was written with Python, but requires virtualenv and flask to be installed.
All integrated HTML for web version uses localhost:5000 for development testing.
Written by Chad Jordan
1/11/2025 
'''
from flask import Flask, render_template, request, redirect, url_for
import sqlite3

app = Flask(__name__)

# Database initialization
def init_db():
    conn = sqlite3.connect('expenses.db')
    c = conn.cursor()
    c.execute('''CREATE TABLE IF NOT EXISTS expenses (
                    id INTEGER PRIMARY KEY AUTOINCREMENT,
                    date TEXT NOT NULL,
                    category TEXT NOT NULL,
                    amount REAL NOT NULL,
                    description TEXT
                )''')
    conn.commit()
    conn.close()

# Home route: display expenses
@app.route('/')
def index():
    conn = sqlite3.connect('expenses.db')
    c = conn.cursor()
    c.execute('SELECT * FROM expenses ORDER BY date DESC')
    expenses = c.fetchall()
    conn.close()
    return render_template('index.html', expenses=expenses)

# Add expense route
@app.route('/add', methods=['GET', 'POST'])
def add():
    if request.method == 'POST':
        date = request.form['date']
        category = request.form['category']
        amount = request.form['amount']
        description = request.form['description']

        conn = sqlite3.connect('expenses.db')
        c = conn.cursor()
        c.execute('INSERT INTO expenses (date, category, amount, description) VALUES (?, ?, ?, ?)',
                  (date, category, amount, description))
        conn.commit()
        conn.close()
        return redirect(url_for('index'))
    return render_template('add.html')

# Delete expense route
@app.route('/delete/<int:expense_id>')
def delete(expense_id):
    conn = sqlite3.connect('expenses.db')
    c = conn.cursor()
    c.execute('DELETE FROM expenses WHERE id = ?', (expense_id,))
    conn.commit()
    conn.close()
    return redirect(url_for('index'))

if __name__ == '__main__':
    init_db()
    app.run(debug=True)

# HTML Templates
# index.html
index_html = """
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Expense Tracker</title>
    <style>
        body { font-family: Arial, sans-serif; margin: 20px; }
        table { width: 100%; border-collapse: collapse; margin-bottom: 20px; }
        th, td { border: 1px solid #ccc; padding: 8px; text-align: left; }
        th { background-color: #f4f4f4; }
        a { text-decoration: none; color: #007BFF; }
        a:hover { text-decoration: underline; }
    </style>
</head>
<body>
    <h1>Expense Tracker</h1>
    <a href="/add">Add New Expense</a>
    <table>
        <thead>
            <tr>
                <th>Date</th>
                <th>Category</th>
                <th>Amount</th>
                <th>Description</th>
                <th>Actions</th>
            </tr>
        </thead>
        <tbody>
            {% for expense in expenses %}
            <tr>
                <td>{{ expense[1] }}</td>
                <td>{{ expense[2] }}</td>
                <td>${{ expense[3] }}</td>
                <td>{{ expense[4] }}</td>
                <td><a href="/delete/{{ expense[0] }}">Delete</a></td>
            </tr>
            {% endfor %}
        </tbody>
    </table>
</body>
</html>
"""

# add.html
add_html = """
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add Expense</title>
    <style>
        body { font-family: Arial, sans-serif; margin: 20px; }
        form { max-width: 400px; margin: auto; }
        label { display: block; margin: 10px 0 5px; }
        input, textarea { width: 100%; padding: 8px; margin-bottom: 10px; border: 1px solid #ccc; border-radius: 4px; }
        button { padding: 10px 15px; background-color: #007BFF; color: #fff; border: none; border-radius: 4px; cursor: pointer; }
        button:hover { background-color: #0056b3; }
        a { text-decoration: none; color: #007BFF; display: inline-block; margin-top: 10px; }
    </style>
</head>
<body>
    <h1>Add Expense</h1>
    <form method="POST">
        <label for="date">Date</label>
        <input type="date" id="date" name="date" required>

        <label for="category">Category</label>
        <input type="text" id="category" name="category" required>

        <label for="amount">Amount</label>
        <input type="number" step="0.01" id="amount" name="amount" required>

        <label for="description">Description</label>
        <textarea id="description" name="description" rows="3"></textarea>

        <button type="submit">Add Expense</button>
    </form>
    <a href="/">Back to Home</a>
</body>
</html>
"""

with open('templates/index.html', 'w') as file:
    file.write(index_html)

with open('templates/add.html', 'w') as file:
    file.write(add_html)
